@@ -3,7 +3,7 @@
 # If you want to add a Browser to extend AWStats database detection capabilities,
 # you must add an entry in BrowsersSearchIDOrder and in BrowsersHashIDLib.
 #-------------------------------------------------------
-# $Revision: 1.55 $ - $Author: eldy $ - $Date: 2007/04/02 18:30:53 $
+# $Revision: 1.60 $ - $Author: eldy $ - $Date: 2008/09/07 14:05:59 $
 
 # 2006-05-15 Sean Carlos http://www.antezeta.com/awstats.html 
 # 				akregator (rss)
@@ -16,13 +16,12 @@
 #				Gregarius devlog.gregarius.net/docs/ua (rss)
 #				hatena rss http://r.hatena.ne.jp/ (rss)
 #				Liferea http://liferea.sourceforge.net/ (rss)
-#				lilina http://lilina.sourceforge.net/ (rss)
 #				PubSub-RSS-Reader http://www.pubsub.com/ (rss)
 # 2006-05-20 Sean Carlos http://www.antezeta.com/awstats.html
 #				Potu Rss-Reader http://www.potu.com/
 #				OSSProxy http://www.marketscore.com/FAQ.Aspx
 
-#				
+		
 #package AWSUA;
 
 
@@ -34,6 +33,7 @@
 #-------------------------------------------------------
 @BrowsersSearchIDOrder = (
 # Most frequent standard web browsers are first in this list (except msie, netscape and firefox)
+'chrome',
 'firebird',
 'go!zilla',
 'icab',
@@ -86,7 +86,7 @@
 'msfrontpageexpress',
 'phoenix',
 'shiira',               # Must be before safari
-'safari',
+'safari',				# Must be after a lot of others (shiira, chrome)
 'tzgeturl',
 'viking',
 'webfetcher',
@@ -122,6 +122,7 @@
 'applesyndication',
 'betanews_reader',
 'blogbridge',
+'cyndicate',
 'feeddemon', 
 'feedreader', 
 'feedtools',
@@ -130,14 +131,13 @@
 'hatena_rss', 
 'jetbrains_omea', 
 'liferea',
-'lilina',
 'netnewswire', 
 'newsfire', 
 'newsgator', 
 'newzcrawler',
 'plagger',
 'pluck', 
-'potu_rss\-reader',
+'potu',
 'pubsub\-rss\-reader',
 'pulpfiction', 
 'rssbandit', 
@@ -219,6 +219,7 @@
 'firefox','Firefox',
 'svn', 'Subversion client', 
 
+'chrome','Google Chrome',
 'firebird','Firebird (Old Firefox)',
 'go!zilla','Go!Zilla',
 'icab','iCab',
@@ -307,6 +308,7 @@
 'applesyndication','<a href="http://www.apple.com/macosx/features/safari/" title="Browser home page [new window]" target="_blank">AppleSyndication (RSS Reader)</a>',
 'betanews_reader','Betanews Reader (RSS Reader)',
 'blogbridge','<a href="http://www.blogbridge.com/" title="Browser home page [new window]" target="_blank">BlogBridge (RSS Reader)</a>',
+'cyndicate','Cyndicate (RSS Reader)',
 'feeddemon', 'FeedDemon (RSS Reader)',
 'feedreader', 'FeedReader (RSS Reader)',
 'feedtools','<a href="http://sporkmonger.com/projects/feedtools/" title="Browser home page [new window]" target="_blank">FeedTools (RSS Reader)</a>',
@@ -315,14 +317,13 @@
 'hatena_rss','<a href="http://r.hatena.ne.jp/" title="Browser home page [new window]" target="_blank">Hatena (RSS Reader)</a>',
 'jetbrains_omea', 'Omea (RSS Reader)',
 'liferea','<a href="http://liferea.sourceforge.net/" title="Browser home page [new window]" target="_blank">Liferea (RSS Reader)</a>',
-'lilina','<a href="http://lilina.sourceforge.net/" title="Browser home page [new window]" target="_blank">lilina (RSS Reader)</a>',
 'netnewswire', 'NetNewsWire (RSS Reader)',
 'newsfire', 'NewsFire (RSS Reader)',
 'newsgator', 'NewsGator (RSS Reader)',
 'newzcrawler', 'NewzCrawler (RSS Reader)',
 'plagger', 'Plagger (RSS Reader)',
 'pluck', 'Pluck (RSS Reader)',
-'potu_rss\-reader','<a href="http://www.potu.com/" title="Potu Rss-Reader home page [new window]" target="_blank">Potu (RSS Reader)</a>',
+'potu','<a href="http://www.potu.com/" title="Potu Rss-Reader home page [new window]" target="_blank">Potu (RSS Reader)</a>',
 'pubsub\-rss\-reader','<a href="http://www.pubsub.com/" title="Browser home page [new window]" target="_blank">PubSub (RSS Reader)</a>',
 'pulpfiction', 'PulpFiction (RSS Reader)',
 'rssbandit', 'RSS Bandit (RSS Reader)',
@@ -422,7 +423,8 @@
 'msie','msie',
 'netscape','netscape',
 'firefox','firefox',
-'svn','subversion', 
+'svn','subversion',
+'chrome','chrome', 
 'firebird','phoenix',
 'go!zilla','gozilla',
 'icab','icab',
@@ -512,7 +514,6 @@
 'webtv','webtv',
 # Anonymous Proxy Browsers (can be used as grabbers as well...)
 'cjb\.net','cjbnet',
-'ossproxy','ossproxy',
 # RSS Readers
 'abilon', 'abilon',
 'aggrevator', 'rss',
@@ -528,14 +529,13 @@
 'hatena_rss', 'rss',
 'jetbrains_omea', 'rss',
 'liferea', 'rss',
-'lilina', 'rss',
 'netnewswire', 'rss',
 'newsfire', 'rss',
 'newsgator', 'rss',
 'newzcrawler', 'rss',
 'plagger', 'rss',
 'pluck', 'rss',
-'potu_rss\-reader', 'rss',
+'potu', 'rss',
 'pubsub\-rss\-reader', 'rss',
 'pulpfiction', 'rss',
 'rssbandit', 'rss',
