@@ -3,9 +3,24 @@
 # If you want to add a Browser to extend AWStats database detection capabilities,
 # you must add an entry in BrowsersSearchIDOrder and in BrowsersHashIDLib.
 #-------------------------------------------------------
-# Originale version by malu
-# $Revision: 1.5 $ - $Author: eldy $ - $Date: 2005/12/20 12:43:51 $
+# $Revision: 1.7 $ - $Author: eldy $ - $Date: 2008/09/07 14:05:59 $
 
+# Originale version by malu
+# 2006-05-15 Sean Carlos http://www.antezeta.com/awstats.html 
+# 				akregator (rss)
+#				AppleSyndication  (rss)
+#				BlogBridge http://www.blogbridge.com/ (rss)
+#				BonEcho (Firefox 2.0 alpha)
+#				FeedTools http://sporkmonger.com/projects/feedtools/ (rss)
+#				gnome\-vfs.*neon http://www.webdav.org/neon/
+#				GreatNews  http://www.curiostudio.com/ (rss)
+#				Gregarius devlog.gregarius.net/docs/ua (rss)
+#				hatena rss http://r.hatena.ne.jp/ (rss)
+#				Liferea http://liferea.sourceforge.net/ (rss)
+#				PubSub-RSS-Reader http://www.pubsub.com/ (rss)
+# 2006-05-20 Sean Carlos http://www.antezeta.com/awstats.html
+#				Potu Rss-Reader http://www.potu.com/
+#				OSSProxy http://www.marketscore.com/FAQ.Aspx
 
 #package AWSUA;
 
@@ -18,6 +33,7 @@
 #-------------------------------------------------------
 @BrowsersSearchIDOrder = (
 # Most frequent standard web browsers are first in this list (except msie, netscape and firefox)
+'chrome',
 'firebird',
 'go!zilla',
 'icab',
@@ -32,12 +48,15 @@
 'amaya',
 'amigavoyager',
 'aweb',
+'bonecho',
 'bpftp',
 'camino',
 'chimera',
 'cyberdog',
 'dillo',
+'doris',
 'dreamcast',
+'xbox',
 'downloadagent',
 'ecatch',
 'emailsiphon',
@@ -46,12 +65,15 @@
 'friendlyspider',
 'fresco',
 'galeon',
+'flashget',
+'freshdownload',
 'getright',
+'leechget',
+'netants',
 'headdump',
 'hotjava',
 'ibrowse',
 'intergo',
-'javaws',
 'k\-meleon',
 'linemodebrowser',
 'lotus\-notes',
@@ -64,7 +86,7 @@
 'msfrontpageexpress',
 'phoenix',
 'shiira',               # Must be before safari
-'safari',
+'safari',				# Must be after a lot of others (shiira, chrome)
 'tzgeturl',
 'viking',
 'webfetcher',
@@ -85,30 +107,51 @@
 'jetaudio',
 'mint_audio',
 'mpg123',
+'mplayer',
 'nsplayer',
+'qts',
 'sonique',
 'uplayer',
-'xmms',
 'xaudio',
+'xine',
+'xmms',
 # RSS Readers
+'abilon',
 'aggrevator', 
+'akregator',
+'applesyndication',
+'betanews_reader',
+'blogbridge',
+'cyndicate',
 'feeddemon', 
 'feedreader', 
-'jetbrains_omea_reader', 
+'feedtools',
+'greatnews',
+'gregarius',
+'hatena_rss', 
+'jetbrains_omea', 
+'liferea',
 'netnewswire', 
 'newsfire', 
 'newsgator', 
 'newzcrawler',
+'plagger',
 'pluck', 
+'potu',
+'pubsub\-rss\-reader',
 'pulpfiction', 
 'rssbandit', 
 'rssreader',
 'rssowl', 
+'rss\sxpress',
+'rssxpress',
 'sage', 
 'sharpreader', 
 'shrook', 
 'straw', 
 'syndirella', 
+'vienna',
+'wizz\srss\snews\sreader',
 # PDA/Phonecell browsers
 'alcatel\-be4',
 'alcatel\-be5',
@@ -505,22 +548,44 @@
 'n21i',
 'n22i',
 'ts21i',
+# PDA/Phonecell I-Mode browsers
+'docomo',
 'portalmmm',
 'ipcheck',
 'cnf2',
 # Others (TV)
 'webtv',
+# Anonymous Proxy Browsers (can be used as grabbers as well...)
+'cjb\.net',
+'ossproxy',
 # Other kind of browsers
 'apt',
+'analogx_proxy',
+'gnome\-vfs',
+'neon',
 'curl',
 'csscheck',
+'httrack',
+'fdm',
+'javaws',
 'wget',
+'chilkat',
+'webdownloader\sfor\sx',
 'w3m',
 'wdg_validator',
+'webreaper',
 'webzip',
 'staroffice',
+'gnus',
+'nikto',
+'microsoft\-webdav\-miniredir',
+'microsoft\sdata\saccess\sinternet\spublishing\sprovider\scache\smanager',
+'microsoft\sdata\saccess\sinternet\spublishing\sprovider\sdav',
+'microsoft\sdata\saccess\sinternet\spublishing\sprovider\sprotocol\sdiscovery',
+'POE\-Component\-Client\-HTTP',
 'mozilla',				# Must be at end because a lot of browsers contains mozilla in string
-'libwww'				# Must be at end because some browser have both 'browser id' and 'libwww'
+'libwww',				# Must be at end because some browser have both 'browser id' and 'libwww'
+'lwp'
 );
 
 # BrowsersHashIDLib
@@ -531,7 +596,9 @@
 'msie','MS Internet Explorer',
 'netscape','Netscape',
 'firefox','Firefox',
+'svn', 'Subversion client', 
 
+'chrome','Google Chrome',
 'firebird','Firebird (Old Firefox)',
 'go!zilla','Go!Zilla',
 'icab','iCab',
@@ -546,12 +613,15 @@
 'amaya','Amaya',
 'amigavoyager','AmigaVoyager',
 'aweb','AWeb',
+'bonecho','<a href="http://www.mozilla.org/projects/bonecho/" title="Browser home page [new window]" target="_blank">BonEcho (Firefox 2.0 development)</a>',
 'bpftp','BPFTP',
 'camino','Camino',
 'chimera','Chimera (Old Camino)',
 'cyberdog','Cyberdog',
 'dillo','Dillo',
+'doris','Doris (for Symbian)',
 'dreamcast','Dreamcast',
+'xbox', 'XBoX',
 'downloadagent','DownloadAgent',
 'ecatch', 'eCatch',
 'emailsiphon','EmailSiphon',
@@ -560,7 +630,11 @@
 'friendlyspider','FriendlySpider',
 'fresco','ANT Fresco',
 'galeon','Galeon',
+'flashget','FlashGet',
+'freshdownload','FreshDownload',
 'getright','GetRight',
+'leechget','LeechGet',
+'netants','NetAnts',
 'headdump','HeadDump',
 'hotjava','Sun HotJava',
 'ibrowse','iBrowse',
@@ -598,30 +672,51 @@
 'jetaudio','JetAudio (media player)',
 'mint_audio','Mint Audio (media player)',
 'mpg123','mpg123 (media player)',
+'mplayer','The Movie Player (media player)',
 'nsplayer','NetShow Player (media player)',
+'qts','Quicktime',
 'sonique','Sonique (media player)',
 'uplayer','Ultra Player (media player)',
-'xmms','XMMS (media player)',
 'xaudio','Some XAudio Engine based MPEG player (media player)',
+'xine','Xine, a free multimedia player (media player)',
+'xmms','XMMS (media player)',
 # RSS Readers
+'abilon','Abilon (RSS Reader)',
 'aggrevator', 'Aggrevator (RSS Reader)',
+'akregator','<a href="http://akregator.sourceforge.net/" title="Browser home page [new window]" target="_blank">Akregator (RSS Reader)</a>',  
+'applesyndication','<a href="http://www.apple.com/macosx/features/safari/" title="Browser home page [new window]" target="_blank">AppleSyndication (RSS Reader)</a>',
+'betanews_reader','Betanews Reader (RSS Reader)',
+'blogbridge','<a href="http://www.blogbridge.com/" title="Browser home page [new window]" target="_blank">BlogBridge (RSS Reader)</a>',
+'cyndicate','Cyndicate (RSS Reader)',
 'feeddemon', 'FeedDemon (RSS Reader)',
 'feedreader', 'FeedReader (RSS Reader)',
-'jetbrains_omea_reader', 'Omea Reader (RSS Reader)',
+'feedtools','<a href="http://sporkmonger.com/projects/feedtools/" title="Browser home page [new window]" target="_blank">FeedTools (RSS Reader)</a>',
+'greatnews','<a href="http://www.curiostudio.com/" title="Browser home page [new window]" target="_blank">GreatNews (RSS Reader)</a>',
+'gregarius','<a href="http://devlog.gregarius.net/docs/ua" title="Browser home page [new window]" target="_blank">Gregarius (RSS Reader)</a>',
+'hatena_rss','<a href="http://r.hatena.ne.jp/" title="Browser home page [new window]" target="_blank">Hatena (RSS Reader)</a>',
+'jetbrains_omea', 'Omea (RSS Reader)',
+'liferea','<a href="http://liferea.sourceforge.net/" title="Browser home page [new window]" target="_blank">Liferea (RSS Reader)</a>',
 'netnewswire', 'NetNewsWire (RSS Reader)',
 'newsfire', 'NewsFire (RSS Reader)',
 'newsgator', 'NewsGator (RSS Reader)',
 'newzcrawler', 'NewzCrawler (RSS Reader)',
+'plagger', 'Plagger (RSS Reader)',
 'pluck', 'Pluck (RSS Reader)',
+'potu','<a href="http://www.potu.com/" title="Potu Rss-Reader home page [new window]" target="_blank">Potu (RSS Reader)</a>',
+'pubsub\-rss\-reader','<a href="http://www.pubsub.com/" title="Browser home page [new window]" target="_blank">PubSub (RSS Reader)</a>',
 'pulpfiction', 'PulpFiction (RSS Reader)',
 'rssbandit', 'RSS Bandit (RSS Reader)',
 'rssreader', 'RssReader (RSS Reader)',
 'rssowl', 'RSSOwl (RSS Reader)',
+'rss\sxpress','RSS Xpress (RSS Reader)',
+'rssxpress','RSSXpress (RSS Reader)',
 'sage', 'Sage (RSS Reader)',
 'sharpreader', 'SharpReader (RSS Reader)',
 'shrook', 'Shrook (RSS Reader)',
 'straw', 'Straw (RSS Reader)',
 'syndirella', 'Syndirella (RSS Reader)',
+'vienna', '<a href="http://www.opencommunity.co.uk/vienna2.php" title="Vienna RSS-Reader [new window]" target="_blank">Vienna (RSS Reader)</a>',
+'wizz\srss\snews\sreader','Wizz RSS News Reader (RSS Reader)',
 # PDA/Phonecell browsers
 'alcatel\-be4','Alcatel BE4 (phone)',
 'alcatel\-be5','Alcatel BE5 (phone)',
@@ -1018,23 +1113,44 @@
 'n21i','I-Mode Nec 21i (phone)',
 'n22i','I-Mode Nec 22i (phone)',
 'ts21i','I-Mode Toshiba 21i (phone)',
-'portalmmm','I-Mode inconnu (phone)',
+# PDA/Phonecell I-Mode browsers
+'docomo','I-Mode phone (PDA/Phone browser)',
+'portalmmm','I-Mode phone (PDA/Phone browser)',
 'ipcheck','Supervision IP Check (phone)',
 'cnf2','Supervision I-Mode ByTel (phone)',
 # Others (TV)
 'webtv','WebTV browser',
+# Anonymous Proxy Browsers (can be used as grabbers as well...)
+'cjb\.net','<a href="http://proxy.cjb.net/" title="Browser home page [new window]" target="_blank">CJB.NET Proxy</a>',
+'ossproxy','<a href="http://www.marketscore.com/FAQ.Aspx" title="OSSProxy home page [new window]" target="_blank">OSSProxy</a>',
 # Other kind of browsers
 'apt','Debian APT',
+'analogx_proxy','AnalogX Proxy',
+'gnome\-vfs', 'Gnome FileSystem Abstraction library', 
+'neon', 'Neon HTTP and WebDAV client library',
 'curl','Curl',
 'csscheck','WDG CSS Validator',
+'httrack','HTTrack',
+'fdm','<a href="http://www.freedownloadmanager.org/" title="Browser home page [new window]" target="_blank">FDM Free Download Manager</a>',
 'javaws','Java Web Start',
 'wget','Wget',
+'chilkat', 'Chilkat',
+'webdownloader\sfor\sx','Downloader for X',
 'w3m','w3m',
 'wdg_validator','WDG HTML Validator',
+'webreaper','WebReaper',
 'webzip','WebZIP',
 'staroffice','StarOffice',
+'gnus', 'Gnus Network User Services',
+'nikto', 'Nikto Web Scanner',
+'microsoft\-webdav\-miniredir', 'Microsoft Data Access Component Internet Publishing Provider',
+'microsoft\sdata\saccess\sinternet\spublishing\sprovider\scache\smanager', 'Microsoft Data Access Component Internet Publishing Provider Cache Manager',
+'microsoft\sdata\saccess\sinternet\spublishing\sprovider\sdav', 'Microsoft Data Access Component Internet Publishing Provider DAV',
+'microsoft\sdata\saccess\sinternet\spublishing\sprovider\sprotocol\sdiscovery', 'Microsoft Data Access Component Internet Publishing Provider Protocol Discovery',
+'POE\-Component\-Client\-HTTP','HTTP user-agent for POE (portable networking framework for Perl)',
 'mozilla','Mozilla',
 'libwww','LibWWW',
+'lwp','LibWWW-perl'
 );
 
 
@@ -1047,7 +1163,11 @@
 'webcapture','1',
 'webcopier','1',
 'curl','1',
+'fdm','1',
+'httrack','1',
+'webreaper','1',
 'wget','1',
+'webdownloader\sfor\sx','1',
 'webzip','1'
 );
 
@@ -1061,7 +1181,8 @@
 'msie','msie',
 'netscape','netscape',
 'firefox','firefox',
-
+'svn','subversion',
+'chrome','chrome',
 'firebird','phoenix',
 'go!zilla','gozilla',
 'icab','icab',
@@ -1074,18 +1195,24 @@
 'amigavoyager','amigavoyager',
 'avantbrowser','avant',
 'aweb','aweb',
+'bonecho','firefox',
 'bpftp','bpftp',
 'camino','chimera',
 'chimera','chimera',
 'cyberdog','cyberdog',
 'dillo','dillo',
+'doris','doris',
 'dreamcast','dreamcast',
+'xbox', 'winxbox',
 'ecatch','ecatch',
 'encompass','encompass',
 'epiphany','epiphany',
 'fresco','fresco',
 'galeon','galeon',
+'flashget','flashget',
+'freshdownload','freshdownload',
 'getright','getright',
+'leechget','leechget',
 'hotjava','hotjava',
 'ibrowse','ibrowse',
 'k\-meleon','kmeleon',
@@ -1103,7 +1230,7 @@
 'webcopier','webcopier',
 # Media only browsers
 'real','real',
-'winamp','winamp',				# Works for winampmpeg and winamp3httprdr
+'winamp','mediaplayer',				# Works for winampmpeg and winamp3httprdr
 'windows\-media\-player','mplayer',
 'audion','mediaplayer',
 'freeamp','mediaplayer',
@@ -1111,436 +1238,72 @@
 'jetaudio','mediaplayer',
 'mint_audio','mediaplayer',
 'mpg123','mediaplayer',
+'mplayer','mediaplayer',
 'nsplayer','netshow',
+'qts','mediaplayer',
 'sonique','mediaplayer',
 'uplayer','mediaplayer',
-'xmms','mediaplayer',
 'xaudio','mediaplayer',
-# RSS Readers
-'aggrevator', 'rss',
-'feeddemon', 'feeddemon',
-'feedreader', 'feedreader',
-'jetbrains_omea_reader', 'jetbrains_omea',
-'netnewswire', 'netnewswire',
-'newsfire', 'newsfire',
-'newsgator', 'newsgator',
-'newzcrawler', 'newscrawler',
-'pluck', 'pluck',
-'pulpfiction', 'pulpfiction',
-'rssbandit', 'rssbandit',
-'rssreader', 'rssreader',
-'rssowl', 'rssowl',
-'sage', 'rss',
-'sharpreader', 'sharpreader',
-'shrook', 'shrook',
-'straw', 'rss',
-'syndirella', 'rss',
-# PDA/Phonecell browsers
-'alcatel\-bf4','alcatel',
-'alcatel\-bf3','alcatel',
-'alcatel\-be4','alcatel',
-'alcatel\-be5','alcatel',
-'alcatel\-bf5','alcatel',
-'alcatel\-bg3','alcatel',
-'alcatel\-bh4','alcatel',
-'auditautomatic','bytel',
-'ericssont68','sony',
-'lg\-g7000','lg',
-'mot\-c350m','motorola',
-'mot\-c4','motorola',
-'mot\-cb','motorola',
-'mot\-d4','motorola',
-'mot\-d8','motorola',
-'mot\-e1','motorola',
-'mot\-f6','motorola',
-'mot\-pan4','motorola',
-'mot\-phx4','motorola',
-'mot\-sap4','motorola',
-'mot\-t720','motorola',
-'mot\-ta02','motorola',
-'mot\-v66m','motorola',
-'mot\-v708','motorola',
-'mot\-8300','motorola',
-'mot\-a\-86','motorola',
-'mot\-af','motorola',
-'mot\-c2','motorola',
-'mot\-c350','motorola',
-'mot\-c550','motorola',
-'mot\-c650','motorola',
-'mot\-cf','motorola',
-'mot\-f5','motorola',
-'mot\-fe','motorola',
-'mot\-t280','motorola',
-'mot\-v300','motorola',
-'mot\-v400','motorola',
-'mot\-v500','motorola',
-'mot\-v525','motorola',
-'mot\-v600','motorola',
-'mot\-v60m','motorola',
-'mot\-v80','motorola',
-'mot\-v810','motorola',
-'nokia3650','nokia',
-'nokia6100','nokia',
-'nokia6800','nokia',
-'nokia7250','nokia',
-'panasonic\-gad35','panasonic',
-'panasonic\-gad6\*','panasonic',
-'panasonic\-g50','panasonic',
-'panasonic\-g60','panasonic',
-'panasonic\-x60','panasonic',
-'panasonic\-x70','panasonic',
-'panasonic\-gad95','panasonic',
-'panasonic\-gad76','panasonic',
-'panasonic\-gad96','panasonic',
-'panasonic\-gad75','panasonic',
-'panasonic\-gad67','panasonic',
-'panasonic\-gad68','panasonic',
-'panasonic\-gad87','panasonic',
-'panasonic\-gad88','panasonic',
-'philips\-fisio_625','philips',
-'philips\-fisio_820','philips',
-'philips\-fisio_822','philips',
-'philips\-fisio_825','philips',
-'philips\-v21wap','philips',
-'r380','ericsson',
-'r600','ericsson',
-'sagem\-3xxx','sagem',
-'sagem\-9xx','sagem',
-'sagem\-myx\-2','sagem',
-'sagem\-myx\-6','sagem',
-'samsung\-sgh\-e700','samsung',
-'samsung\-sgh\-s500','samsung',
-'samsung\-sgh\-t500','samsung',
-'samsung\-sgh\-a300','samsung',
-'samsung\-sgh\-a400','samsung',
-'samsung\-sgh\-a800','samsung',
-'samsung\-sgh\-n100','samsung',
-'samsung\-sgh\-n400','samsung',
-'samsung\-sgh\-n500','samsung',
-'samsung\-sgh\-r200','samsung',
-'samsung\-sgh\-t400','samsung',
-'samsung\-sgh\-s100','samsung',
-'samsung\-sgh\-t100','samsung',
-'samsung\-sgh\-t400','samsung',
-'samsung\-sgh\-v200','samsung',
-'samsung\_sgh\-x100','samsung',
-'samsung\-sgh\-e100','samsung',
-'samsung\-sgh\-e708','samsung',
-'samsung\-sgh\-e800','samsung',
-'samsung\-sgh\-x100','samsung',
-'samsung\-sgh\-x600','samsung',
-'sec\-sghc100','samsung',
-'sec\-sghp100','samsung',
-'sec\-sghp400','samsung',
-'sec\-sghq200','samsung',
-'sec\-sghs200','samsung',
-'sec\-spha460','samsung',
-'sec\-sghs100','samsung',
-'sec\-sghs300','samsung',
-'sec\-sghv200','samsung',
-'sec\-sghv205','samsung',
-'sec\-sghe410','samsung',
-'sec\-sghe400','samsung',
-'sec\-sghe600','samsung',
-'sec\-sghe710','samsung',
-'sec\-sghe715','samsung',
-'sec\-sghs105','samsung',
-'sec\-sghx105','samsung',
-'sec\-sghx426','samsung',
-'sec\-sghx427','samsung',
-'sec\-sghx430','samsung',
-'sec\-sghx450','samsung',
-'sharp\-tq\-gx12','sharp',
-'sie\-c3i','siemens',
-'sie\-s35','siemens',
-'sie\-s40','siemens',
-'sie\-s55','siemens',
-'sie\-sl45','siemens',
-'sie\-slik','siemens',
-'sie\-a57','siemens',
-'sie\-a60','siemens',
-'sie\-c56','siemens',
-'sie\-c61','siemens',
-'sie\-cf62','siemens',
-'sie\-m65','siemens',
-'sie\-s56','siemens',
-'sie\-s57c','siemens',
-'sie\-s65','siemens',
-'sie\-sl5e','siemens',
-'sie\-st60','siemens',
-'sie\-sx1','siemens',
-'sonyericssont100','sony',
-'sonyericssont310','sony',
-'sonyericssont610','sony',
-'sonyericssont620','sony',
-'sonyericssont630','sony',
-'sonyericssont68','sony',
-'t66','sony',
-'mot\-f0','motorola',
-'mot\-d5','motorola',
-'nokia3100','nokia',
-'nokia3200','nokia',
-'nokia3560','nokia',
-'nokia3595','nokia',
-'nokia6220','nokia',
-'nokia8265','nokia',
-'nokia3300','nokia',
-'nokia3530','nokia',
-'nokia3590','nokia',
-'nokia6108','nokia',
-'nokia6211','nokia',
-'nokia6600','nokia',
-'nokia6650','nokia',
-'nokia9210','nokia',
-'nokian\-gage','nokia',
-'nokia5510','nokia',
-'nokia5210','nokia',
-'nokia8310','nokia',
-'nokia6500','nokia',
-'nokia7650','nokia',
-'nokia6510','nokia',
-'nokia8855','nokia',
-'nokia6310i','nokia',
-'nokia3510','nokia',
-'nokia3410','nokia',
-'nokia3350','nokia',
-'nokia8910','nokia',
-'nokia9210i','nokia',
-'nokia3210','nokia',
-'nokia3310','nokia',
-'nokia3330','nokia',
-'nokia5110','nokia',
-'nokia5130','nokia',
-'nokia6110','nokia',
-'nokia6130','nokia',
-'nokia6150','nokia',
-'nokia6210','nokia',
-'nokia6250','nokia',
-'nokia6310\/','nokia',
-'nokia7110','nokia',
-'nokia8110i','nokia',
-'nokia8210','nokia',
-'nokia8810','nokia',
-'nokia8850','nokia',
-'nokia8890','nokia',
-'nokia9000','nokia',
-'nokia9110','nokia',
-'nokia7210','nokia',
-'nokia5100','nokia',
-'nokia6610','nokia',
-'nokia3660','nokia',
-'nokia6230','nokia',
-'nokia6340i','nokia',
-'nokia6810','nokia',
-'nokia6820','nokia',
-'nokia7200','nokia',
-'nokia7600','nokia',
-'nokia7610','nokia',
-'philips\-az\@lis268','philips',
-'philips\-az\@lis288','philips',
-'philips\-fisio120','philips',
-'philips\-fisio121','philips',
-'philips\-fisio610','philips',
-'philips\-fisio620','philips',
-'philips\-fisio820','philips',
-'philips\-fisio316','philips',
-'philips\-az\@lis238','philips',
-'philips\-fisio311','philips',
-'philips\-fisio312','philips',
-'philips\-xenium9\@9','philips',
-'philips\-fisio625','philips',
-'philips\-fisio825','philips',
-'sagem\-myx\-5d','sagem',
-'sagem\-myx\-5m','sagem',
-'sagem\-myx\-3','sagem',
-'sagem\-myx\-5/','sagem',
-'samsung\-sgh\-n620','samsung',
-'samsung\-sgh\-n600','samsung',
-'samsung\-sgh\-t100','samsung',
-'samsung\-sgh\-s100','samsung',
-'samsung\-sgh\-r210','samsung',
-'samsung\-sgh\-r200s','samsung',
-'samsung\-sgh\-v200','samsung',
-'mitsu','trium',
-'sie\-2128','siemens',
-'sie\-6618','siemens',
-'sie\-a55','siemens',
-'sie\-c60','siemens',
-'sie\-c62','siemens',
-'sie\-m55','siemens',
-'sie\-mc60','siemens',
-'sie\-sl55','siemens',
-'sie\-slin','siemens',
-'sie\-me45','siemens',
-'sie\-c45','siemens',
-'sie\-s45','siemens',
-'sie\-m50','siemens',
-'sie\-mt50','siemens',
-'sie\-c55','siemens',
-'sie\-a50','siemens',
-'ericssonr520','sony',
-'ericssont20','sony',
-'ericssont39','sony',
-'ericssont39','sony',
-'ericssont65','sony',
-'ericssont66','sony',
-'sonyericssonp900','sony',
-'sonyericssont230','sony',
-'sonyericssont306','sony',
-'sonyericssont316','sony',
-'sonyericssont616','sony',
-'sonyericssonz600','sony',
-'sonyericssont68/','sony',
-'sonyericssont68i','sony',
-'sonyericssont200','sony',
-'sonyericssont300','sony',
-'sonyericssont600','sony',
-'sonyericssonp800','sony',
-'lg\-c1100','lg',
-'lg\-c1200','lg',
-'lg\-c2200','lg',
-'lg\-g1500','lg',
-'lg\-g3100','lg',
-'lg\-g4015','lg',
-'lg\-g5300','lg',
-'lg\-g5400','lg',
-'lg\-g7050','lg',
-'lg\-g7100','lg',
-'lg\-l1100','lg',
-'lg\-l1200','lg',
-'mot\-85','motorola',
-'mot\-a\-0a','motorola',
-'mot\-a\-2b','motorola',
-'mot\-c357','motorola',
-'mot\-c380','motorola',
-'mot\-e398','motorola',
-'mot\-v180','motorola',
-'mot\-v220','motorola',
-'mot\-v3','motorola',
-'mot\-v980','motorola',
-'nokia2650','nokia',
-'nokia3108','nokia',
-'nokia3120','nokia',
-'nokia3220','nokia',
-'nokia5140','nokia',
-'nokia6010','nokia',
-'nokia6170','nokia',
-'nokia6260','nokia',
-'nokia6630','nokia',
-'nokia6670','nokia',
-'nokia7260','nokia',
-'sie\-a65','siemens',
-'sie\-c65','siemens',
-'sie\-c6v','siemens',
-'sie\-cx65','siemens',
-'sie\-cx70','siemens',
-'sie\-sl65','siemens',
-'sonyericssonk500i','sony',
-'sonyericssonk700c','sony',
-'sonyericssonk700i','sony',
-'sonyericssonp910i','sony',
-'sonyericssons700i','sony',
-'sonyericssont226','sony',
-'sonyericssont628','sony',
-'sonyericssonz1010','sony',
-'sonyericssonz200','sony',
-'alcatel\-be3','alcatel',
-'alcatel\-oh5','alcatel',
-'alcatel\-th3','alcatel',
-'alcatel\-th4','alcatel',
-'ericssona2628s','sony',
-'ericssonr320','sony',
-'lg\-c1300','lg',
-'lg\-c3100','lg',
-'lg\-f2100','lg',
-'lg\-g1600','lg',
-'lg\-g210','lg',
-'lg\-g4010','lg',
-'lg\-g510','lg',
-'lg\-g5310','lg',
-'lg\-g5600','lg',
-'lg\-g650','lg',
-'lg\-g7070','lg',
-'lg\-l3100','lg',
-'lg\-t5100','lg',
-'mot\-2200','motorola',
-'mot\-32','motorola',
-'mot\-74','motorola',
-'mot\-76','motorola',
-'mot\-87','motorola',
-'mot\-8700','motorola',
-'mot\-a\-0e','motorola',
-'mot\-a\-1c','motorola',
-'mot\-a760','motorola',
-'mot\-a835','motorola',
-'mot\-c385','motorola',
-'mot\-v26x','motorola',
-'mot\-v290','motorola',
-'mot\-v505','motorola',
-'mot\-v547','motorola',
-'mot\-v551','motorola',
-'mot\-v620','motorola',
-'mot\-v690','motorola',
-'mot\-v878','motorola',
-'sie\-3618','siemens',
-'sie\-a56','siemens',
-'sie\-c6c','siemens',
-'sie\-cx6c','siemens',
-'sie\-cx6v','siemens',
-'sie\-m6c','siemens',
-'sie\-m6v','siemens',
-'sie\-s46','siemens',
-'sie\-sk65','siemens',
-'sie\-sl56','siemens',
-'sie\-st55','siemens',
-'sagem\-mo130','sagem',
-'sagem\-myc','sagem',
-'sagem\-myv','sagem',
-'sagem\-myx3','sagem',
-'sagem\-myx5','sagem',
-'sagem\-myx','sagem',
-'lg\-G610','lg',
-'mot\-v550','motorola',
-'mot\-a\-1f','motorola',
-'mot\-c155','motorola',
-'mot\-c975','motorola',
-'mot\-c980','motorola',
-'mot\-e380','motorola',
-'mot\-e680','motorola',
-'mot\-ed','motorola',
-'mot\-t725e','motorola',
-'mot\-v150','motorola',
-'mot\-v171','motorola',
-'mot\-v535','motorola',
-'mot\-v545','motorola',
-'mot\-v635','motorola',
-'mot\-v870','motorola',
-'nokia2112','nokia',
-'nokia3620','nokia',
-'nokia6020','nokia',
-'nokia6200','nokia',
-'nokia6620','nokia',
-'nokia6680','nokia',
-'nokia7270','nokia',
-'nokia7280','nokia',
-'nokia9500','nokia',
-'panasonic\-a200','panasonic',
-'panasonic\-g70','panasonic',
-'panasonic\-x100','panasonic',
-'panasonic\-x300','panasonic',
-'panasonic\-x400','panasonic',
-'panasonic\-x500','panasonic',
-'panasonic\-x66','panasonic',
-'panasonic\-x77','panasonic',
-'opwv\-sdk','wap gnrique',
-'sharp\-tq\-gx10','sharp',
+'xine','mediaplayer',
+'xmms','mediaplayer',
+# PDA/Phonecell I-Mode browsers
+'docomo','pdaphone',
+'portalmmm','pdaphone',
 # Others (TV)
 'webtv','webtv',
+# Anonymous Proxy Browsers (can be used as grabbers as well...)
+'cjb\.net','cjbnet',
+# RSS Readers
+'abilon', 'abilon',
+'aggrevator', 'rss',
+'akregator', 'rss',
+'applesyndication', 'rss',
+'betanews_reader','rss',
+'blogbridge','rss',
+'feeddemon', 'rss',
+'feedreader', 'rss',
+'feedtools', 'rss',
+'greatnews', 'rss',
+'gregarius', 'rss',
+'hatena_rss', 'rss',
+'jetbrains_omea', 'rss',
+'liferea', 'rss',
+'netnewswire', 'rss',
+'newsfire', 'rss',
+'newsgator', 'rss',
+'newzcrawler', 'rss',
+'plagger', 'rss',
+'pluck', 'rss',
+'potu', 'rss',
+'pubsub\-rss\-reader', 'rss',
+'pulpfiction', 'rss',
+'rssbandit', 'rss',
+'rssreader', 'rss',
+'rssowl', 'rss',
+'rss\sxpress','rss',
+'rssxpress','rss',
+'sage', 'rss',
+'sharpreader', 'rss',
+'shrook', 'rss',
+'straw', 'rss',
+'syndirella', 'rss',
+'vienna', 'rss',
+'wizz\srss\snews\sreader','wizz',
 # Other kind of browsers
 'apt','apt',
+'analogx_proxy','analogx',
+'microsoft\-webdav\-miniredir','frontpage',
+'microsoft\sdata\saccess\sinternet\spublishing\sprovider\scache\smanager','frontpage',
+'microsoft\sdata\saccess\sinternet\spublishing\sprovider\sdav','frontpage',
+'microsoft\sdata\saccess\sinternet\spublishing\sprovider\sprotocol\sdiscovery','frontpage',
+'gnome\-vfs', 'gnome',
+'neon','neon',
 'javaws','java',
 'webzip','webzip',
+'webreaper','webreaper',
+'httrack','httrack',
 'staroffice','staroffice',
+'gnus', 'gnus',
 'mozilla','mozilla'
 );
 
